#!/usr/bin/perl

# Title:       Kernel Security Advisory SUSE-SA:2009:045
# Description: The kernel was updated to fix local privilege escalation security issues, Severity 7 of 10.
# Modified:    2013 Jun 26

##############################################################################
#  Copyright (C) 2013 SUSE LLC
##############################################################################
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; version 2 of the License.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, see <http://www.gnu.org/licenses/>.
#

#  Authors/Contributors:
#   Jason Record (jrecord@suse.com)

##############################################################################

##############################################################################
# Module Definition
##############################################################################

use strict;
use warnings;
use SDP::Core;
use SDP::SUSE;

##############################################################################
# Overriden (eventually or in part) from SDP::Core Module
##############################################################################

@PATTERN_RESULTS = (
	PROPERTY_NAME_CLASS."=Security",
	PROPERTY_NAME_CATEGORY."=SLE",
	PROPERTY_NAME_COMPONENT."=Kernel",
	PROPERTY_NAME_PATTERN_ID."=$PATTERN_ID",
	PROPERTY_NAME_PRIMARY_LINK."=META_LINK_Security",
	PROPERTY_NAME_OVERALL."=$GSTATUS",
	PROPERTY_NAME_OVERALL_INFO."=None",
	"META_LINK_Security=http://www.novell.com/linux/security/advisories/2009_45_kernel.html"
);

##############################################################################
# Main Program Execution
##############################################################################

SDP::Core::processOptions();
	my $ADVISORY = '7';
	my $TYPE = 'Local privilege escalation';
	my $SCOPE = 0;

	if ( SDP::SUSE::securitySeverityKernelCheck(SLE11GA, SLE11SP1, '2.6.27.29-0.1', $ADVISORY, $TYPE) ) {
		SDP::Core::printDebug("OUTSIDE SCOPE", "Not SLE11");
		$SCOPE++;
		if ( SDP::SUSE::securitySeverityKernelCheck(SLE10SP2, SLE10SP3, '2.6.16.60-0.42.4', $ADVISORY, $TYPE) ) {
			SDP::Core::printDebug("OUTSIDE SCOPE", "Not SLE10SP2");
			$SCOPE++;
			if ( SDP::SUSE::securitySeverityKernelCheck(SLE9GA, SLE9SP5, '2.6.5-7.318', $ADVISORY, $TYPE) ) {
				SDP::Core::printDebug("OUTSIDE SCOPE", "Not SLE9");
				$SCOPE++;
			}
		}
	}
	if ( $SCOPE >= 3 ) {
		SDP::Core::updateStatus(STATUS_ERROR, "ABORTED: Kernel Security Advisory: Outside the kernel scope");
	}
SDP::Core::printPatternResults();

exit;

