#!/usr/bin/perl

# Title:       Kernel Security Advisory SUSE-SA:2010:033
# Description: The kernel was updated to fix local privilege escalation security issues, CVSS v2 Base Score: 6.9
# Modified:    2013 Jun 25

##############################################################################
#  Copyright (C) 2013 SUSE LLC
##############################################################################
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; version 2 of the License.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, see <http://www.gnu.org/licenses/>.
#  Authors/Contributors:
#  	Jason Record (jrecord@suse.com)
##############################################################################

##############################################################################
# Module Definition
##############################################################################

use strict;
use warnings;
use SDP::Core;
use SDP::SUSE;

##############################################################################
# Overriden (eventually or in part) from SDP::Core Module
##############################################################################

@PATTERN_RESULTS = (
	PROPERTY_NAME_CLASS."=Security",
	PROPERTY_NAME_CATEGORY."=SLE",
	PROPERTY_NAME_COMPONENT."=Kernel",
	PROPERTY_NAME_PATTERN_ID."=$PATTERN_ID",
	PROPERTY_NAME_PRIMARY_LINK."=META_LINK_Security",
	PROPERTY_NAME_OVERALL."=$GSTATUS",
	PROPERTY_NAME_OVERALL_INFO."=None",
	"META_LINK_Security=http://www.novell.com/linux/security/advisories/2010_33_kernel.html"
);

##############################################################################
# Main Program Execution
##############################################################################

SDP::Core::processOptions();
	my $SEVERITY = '6.9';
	my $TYPE = 'Local privilege escalation';

	if ( SDP::SUSE::securitySeverityKernelCheck(SLE11SP1, SLE11SP2, '2.6.32.13-0.5', $SEVERITY, $TYPE) ) {
		SDP::Core::updateStatus(STATUS_ERROR, "ABORTED: Kernel Security $TYPE Advisory: Outside the kernel scope");
	}
SDP::Core::printPatternResults();

exit;

